import * as _nuxt_schema from '@nuxt/schema';

interface ModuleOptions {
    /**
     * Whether to show debug logs for the module
     */
    debugEnabled: boolean;
    /**
     * Whether events shall be tracked when running the site in development mode
     *
     * @default false
     */
    trackDevMode: boolean;
    /**
     * Whether trackPageView should be automatically integrated with the router
     *
     * @default true
     */
    enableRouterSync: boolean;
    /**
     * Enable Nuxt Devtools integration
     *
     * @default true
     */
    devtools: boolean;
    /**
     * Ignore some router views from being tracked - used when enableRouterSync is true
     */
    ignoredViews: string[] | ((to: any, from: any) => boolean);
    /**
     * Derive additional event data after navigation
     */
    vueRouterAdditionalEventData?: (to: any, from?: any) => Record<string, any> | Promise<Record<string, any>>;
    /**
     * Whether or not call `trackView` in `Vue.nextTick`
     */
    trackOnNextTick: boolean;
    /**
     * Settings for Segment
     *
     * @default {}
     */
    settings: {
        /**
         * Your segment write key - required
         */
        writeKey: string;
        /**
         * The CDN URL to use, if not the default. Using 'undefined' will default to that specified by segment, i.e. https://cdn.segment.com
         *
         * @default undefined
         */
        cdnURL?: string;
    };
    /**
     * Options for Segment
     *
     * @default {}
     */
    options: {
        /**
         * The API host where the events will be sent to
         *
         * @default undefined
         */
        apiHost?: string;
        /**
         * The protocol for the API host. Use with options.apiHost
         *
         * @default undefined
         */
        protocol?: 'http' | 'https';
    };
}
declare module '@nuxt/schema' {
    interface PublicRuntimeConfig {
        segment: ModuleOptions;
    }
    interface NuxtConfig {
        segment?: ModuleOptions;
    }
    interface NuxtOptions {
        segment?: ModuleOptions;
    }
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

export { ModuleOptions, _default as default };
