import { useNuxtApp, useRuntimeConfig } from "#imports";
export function useSegment(segment) {
  const $segment = segment ?? useNuxtApp().$segment;
  const config = useRuntimeConfig().public.segment;
  const logPrefix = shouldTrack() ? "segment" : "segment-mock";
  function shouldTrack() {
    return process.client && (process.env.NODE_ENV !== "development" || config.trackDevMode);
  }
  function identify(...args) {
    if (config.debugEnabled) {
      console.log(`[${logPrefix}@identify]`, ...args);
    }
    if (shouldTrack()) {
      return $segment.identify(...args);
    }
  }
  function page(...args) {
    if (config.debugEnabled) {
      console.log(`[${logPrefix}@page]`, ...args);
    }
    if (shouldTrack()) {
      return $segment.page(...args);
    }
  }
  function track(...args) {
    if (shouldTrack()) {
      if (config.debugEnabled) {
        console.log(`[${logPrefix}@track]`, ...args);
      }
      return $segment.track(...args);
    }
  }
  function trackSubmit(...args) {
    if (shouldTrack()) {
      if (config.debugEnabled) {
        console.log(`[${logPrefix}@trackSubmit]`, ...args);
      }
      return $segment.trackSubmit(...args);
    }
  }
  function trackClick(...args) {
    if (shouldTrack()) {
      if (config.debugEnabled) {
        console.log(`[${logPrefix}@trackClick]`, ...args);
      }
      return $segment.trackClick(...args);
    }
  }
  function trackLink(...args) {
    if (shouldTrack()) {
      if (config.debugEnabled) {
        console.log(`[${logPrefix}@trackLink]`, ...args);
      }
      return $segment.trackLink(...args);
    }
  }
  function raw(name, ...args) {
    if (shouldTrack()) {
      if (config.debugEnabled) {
        console.log(`[${logPrefix}@raw]`, ...args);
      }
      $segment[name](...args);
    }
  }
  return {
    $segment,
    identify,
    page,
    track,
    trackSubmit,
    trackClick,
    trackLink,
    raw
  };
}
